==> 0.0.130.tar.gz: lib/routing/app_screen_router_delegate.dart <==
import 'package:flutter/material.dart';
import 'app_screen.dart';
import 'app_screen_route_path.dart';
import 'app_screens.dart';
import 'initial_values_routing.dart';

class AppScreenRouterDelegate extends RouterDelegate<AppScreenRoutePath>
    with ChangeNotifier, PopNavigatorRouterDelegateMixin<AppScreenRoutePath> {
  final GlobalKey<NavigatorState> navigatorKey;

  AppScreen _selectedAppScreen;
  bool show404 = false;

  AppScreenRouterDelegate() : navigatorKey = GlobalKey<NavigatorState>();

  bool firstTime = true;

  AppScreenRoutePath get currentConfiguration {
    if (firstTime) {
      firstTime = false;
      handleAppScreenOpening = _handleAppScreenOpening;
    }

    if (show404) {
      return AppScreenRoutePath.unknown();
    }
    return _selectedAppScreen == null
        ? AppScreenRoutePath.home()
        : AppScreenRoutePath.details(_selectedAppScreen.name);
  }

  @override
  Widget build(BuildContext context) {
    return Navigator(
      key: navigatorKey,
      pages: [
        MaterialPage(
          key: ValueKey('Landing'),
          child: landingScreen,
        ),
        if (show404)
          MaterialPage(
            key: ValueKey('UnknownPage'),
            child: unknownScreen,
          )
        else if (_selectedAppScreen != null)
          MaterialPage(
            key: ValueKey(_selectedAppScreen.name),
            child: _selectedAppScreen,
          )
      ],
      onPopPage: (route, result) {
        if (!route.didPop(result)) {
          return false;
        }

        Uri uri = Uri.parse(_selectedAppScreen.name);

        if (uri.pathSegments.length > 1) {
          int lastPathSegmentIndex = uri.path.lastIndexOf("/");
          String newPath = uri.path.substring(0, lastPathSegmentIndex);

          AppScreen newScreen =
              appScreens.singleWhere((appScreen) => appScreen.name == newPath);

          _selectedAppScreen = newScreen;
        } else {
          _selectedAppScreen = null;
        }

        show404 = false;
        notifyListeners();

        return true;
      },
    );
  }

  @override
  Future<void> setNewRoutePath(AppScreenRoutePath path) async {
    if (path.isUnknown) {
      _selectedAppScreen = null;
      show404 = true;
      return;
    }

    if (path.isDetailsPage) {
      AppScreen appScreen = appScreens.singleWhere(
          (currentAppScreen) => currentAppScreen.name == path.name, orElse: () {
        return null;
      });

      if (appScreen == null) {
        show404 = true;
        return;
      }

      _selectedAppScreen = appScreen;
    } else {
      _selectedAppScreen = null;
    }

    show404 = false;
  }

  void _handleAppScreenOpening(int index) {
    print("appScreens.lenght: " + appScreens.length.toString());

    print("appScreens index: $index");

    _selectedAppScreen = appScreens[index];

    notifyListeners();
  }
}

==> 0.0.134.tar.gz: lib/routing/app_screen_router_delegate.dart <==
import 'package:flutter/material.dart';
import 'app_screen.dart';
import 'app_screen_route_path.dart';
import 'app_screens.dart';
import 'initial_values_routing.dart';

class AppScreenRouterDelegate extends RouterDelegate<AppScreenRoutePath>
    with ChangeNotifier, PopNavigatorRouterDelegateMixin<AppScreenRoutePath> {
  final GlobalKey<NavigatorState> navigatorKey;

  AppScreen _selectedAppScreen;
  bool show404 = false;

  AppScreenRouterDelegate() : navigatorKey = GlobalKey<NavigatorState>();

  bool firstTime = true;

  AppScreenRoutePath get currentConfiguration {
    if (firstTime) {
      firstTime = false;
      handleAppScreenOpening = _handleAppScreenOpening;
    }

    if (show404) {
      return AppScreenRoutePath.unknown();
    }

    return _selectedAppScreen == null
        ? AppScreenRoutePath.home()
        : AppScreenRoutePath.details(_selectedAppScreen.name);
  }

  @override
  Widget build(BuildContext context) {
    return Navigator(
      key: navigatorKey,
      pages: [
        MaterialPage(
          key: ValueKey('Landing'),
          child: landingScreen,
        ),
        if (show404)
          MaterialPage(
            key: ValueKey('UnknownPage'),
            child: unknownScreen,
          )
        else if (_selectedAppScreen != null)
          MaterialPage(
            key: ValueKey(_selectedAppScreen.name),
            child: _selectedAppScreen,
          )
      ],
      onPopPage: (route, result) {
        if (!route.didPop(result)) {
          return false;
        }

        Uri uri = Uri();
        if (_selectedAppScreen.name != null) {
          uri = Uri.parse(_selectedAppScreen.name);

          if (uri.pathSegments.length > 1) {
            int lastPathSegmentIndex = uri.path.lastIndexOf("/");
            String newPath = uri.path.substring(0, lastPathSegmentIndex);

            AppScreen newScreen = appScreens
                .singleWhere((appScreen) => appScreen.name == newPath);

            _selectedAppScreen = newScreen;
          } else {
            _selectedAppScreen = null;
          }
        } else {
          _selectedAppScreen = null;
        }

        show404 = false;
        notifyListeners();

        return true;
      },
    );
  }

  @override
  Future<void> setNewRoutePath(AppScreenRoutePath path) async {
    if (path.isUnknown) {
      _selectedAppScreen = null;
      show404 = true;
      return;
    }

    if (path.isDetailsPage) {
      AppScreen appScreen = appScreens.singleWhere(
          (currentAppScreen) => currentAppScreen.name == path.name, orElse: () {
        return null;
      });

      if (appScreen == null) {
        show404 = true;
        return;
      }

      _selectedAppScreen = appScreen;
    } else {
      _selectedAppScreen = null;
    }

    show404 = false;
  }

  void _handleAppScreenOpening(int index) {
    print("appScreens.lenght: " + appScreens.length.toString());

    print("appScreens index: $index");

    _selectedAppScreen = appScreens[index];

    notifyListeners();
  }
}
